@@ -51,12 +51,11 @@ atcObject = None
 class gdaAttack:
     """Manages a GDA Attack
 
-       See __init__ for input parameters. <br/>
        WARNING: this code is fragile, and can fail ungracefully, or
        just hang."""
 
     def __init__(self, params):
-        """ Sets everything up with 'gdaAttack(params)'
+        """ Everything gets set up with 'gdaAttack(params)'
 
             params is a dictionary containing the following
             required parameters: <br/>
@@ -175,8 +174,7 @@ class gdaAttack:
         self._claimCounter = 0
         self._guessCounter = 0
         # State for duplicate claim detection
-        # Temp disable because buggy
-        #self._dupCheck = DupCheck()
+        self._dupCheck = DupCheck()
         # State for computing attack results (see _initAtkRes())
         self._atrs = {}
         # State for various operational measures (see _initOp())
@@ -312,13 +310,19 @@ class gdaAttack:
             sys.exit(exitMsg)
 
     def isClaimed(self, spec):
-        # Temp disable because buggy
-        return False
+        """Check if a claim was already fully or partially made.
+
+        The `spec` is formatted identical to the `spec` in `gdaAttack.askClaim`."""
         return self._dupCheck.is_claimed(spec, verbose=self._vb)
 
     def askClaim(self, spec, cache=True, claim=True):
         """Generate Claim query for raw and optionally pub databases.
 
+        Before anything happens, the system uses the `gdaAttack.isClaimed`
+        method to determine whether a previous claim fully or partially
+        matches the new claim. Such duplicates are not allowed and an error
+        will be raised providing additional details about the duplicate.
+
         Making a claim results in a query to the raw database, and if
         linkability attack, the pub database, to check
         the correctness of the claim. Multiple calls to this method will
@@ -341,9 +345,8 @@ class gdaAttack:
         Answers are cached <br/>
         Returns immediately"""
         if self._vb: print(f"Calling {__name__}.askClaim with spec '{spec}', count {self._claimCounter}")
-        # Temp disable because buggy
-        #if not self._dupCheck.is_claimed(spec, verbose=self._vb, raise_true=True):
-            #self._dupCheck.claim(spec, verbose=self._vb)
+        if not self._dupCheck.is_claimed(spec, verbose=self._vb, raise_true=True):
+            self._dupCheck.claim(spec, verbose=self._vb)
         self._claimCounter += 1
         sql = self._makeSqlFromSpec(spec)
         if self._vb: print(f"Sql is '{sql}'")
